#!/bin/sh
# Generated by `baton admin releases stage` for baton-telegram 0.1.0.
set -e
dest="${BATON_INSTALL_BIN:-$HOME/.local/bin}"
mkdir -p "$dest"
for f in baton-telegram; do
	install -m 0755 "./$f" "$dest/$f"
done
echo "baton-telegram 0.1.0: installed baton-telegram -> $dest"
